require 'spec_helper'

describe AlterEgo do

  describe "authorization_url" do
    it "should require an app_id and redirect_url" do
      expect {AlterEgo.authorization_url}.should raise_error(ArgumentError)
      expect {AlterEgo.authorization_url(@app_id)}.should raise_error(ArgumentError)
      expect {AlterEgo.authorization_url(@app_id, @callback_url)}.should_not raise_error(ArgumentError)
    end

    it "should generate an authorization URL" do
      @callback_url = 'https://test.com/callback'
      url = AlterEgo.authorization_url(@app_id, @callback_url)
      url.should eq("#{AlterEgo::AUTH_URL}?id=#{@app_id}&redirect_url=#{URI.escape(@callback_url, Regexp.new("[^#{URI::PATTERN::UNRESERVED}]"))}")
    end
  end

  describe "API" do
    API_URL = "http://alteregoapp.com:443/api/check"
    
    it "should require a key when pinging" do
      expect {AlterEgo.ping}.should raise_error(ArgumentError)
    end
    
    it "should return 'PONG!' when pinging successfully" do
      FakeWeb.register_uri(:get, "#{API_URL}/ping.json?key=#{@api_key}", :body => "PONG!")
      AlterEgo.ping(@api_key).should eq("PONG!")
    end
    
    it "should require a key and passcode when checking password" do
      expect {AlterEgo.password}.should raise_error(ArgumentError)
      expect {AlterEgo.password(@api_key)}.should raise_error(ArgumentError)
    end
    
    it "should return true when the passcode matches" do
      FakeWeb.register_uri(:get, "#{API_URL}/password.json?key=#{@api_key}&pass=#{@passcode}", :body => "true")
      AlterEgo.password(@api_key, @passcode).should eq("true")
    end
    
    it "should return false when the passcode doesn't match" do
      FakeWeb.register_uri(:get, "#{API_URL}/password.json?key=#{@api_key}&pass=#{@passcode}", :body => "false")
      AlterEgo.password(@api_key, @passcode).should eq("false")
    end
    
    it "should respond to 500 errors from the API" do
      FakeWeb.register_uri(:get, "#{API_URL}/password.json?key=#{@api_key}&pass=#{@passcode}", :body => @error, :status => ["500", "Internal Server Error"])
      expect {AlterEgo.password(@api_key, @passcode)}.should raise_error(AlterEgo::APIError)
    end
  end

end